@@ -1,27 +1,12 @@
 /*
  * This file is part of LibKGAPI library
  *
- * Copyright (C) 2013  Daniel Vrátil <dvratil@redhat.com>
+ * SPDX-FileCopyrightText: 2013 Daniel Vrátil <dvratil@redhat.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
-#ifndef LIBKGAPI2_CONTACT_H
-#define LIBKGAPI2_CONTACT_H
+#pragma once
 
 #include "object.h"
 #include "types.h"
@@ -78,7 +63,7 @@ class KGAPICONTACTS_EXPORT Contact : public KGAPI2::Object,
     /**
      * @brief Destructor
      */
-    ~Contact();
+    ~Contact() override;
 
     bool operator==(const Contact &other) const;
 
@@ -90,19 +75,19 @@ class KGAPICONTACTS_EXPORT Contact : public KGAPI2::Object,
     void setDeleted(bool deleted);
 
     /**
-     * @param Returns whether contact is deleted
+     * @brief Returns whether contact is deleted
      */
     bool deleted() const;
 
     /**
-     * @param Sets URL of contact photo.
+     * Sets URL of contact photo.
      *
      * @param photoUrl
      */
     void setPhotoUrl(const QString &photoUrl);
 
     /**
-     * @param Sets URL of contact photo.
+     * Sets URL of contact photo.
      * @overload setPhotoUrl(QString)
      */
     void setPhotoUrl(const QUrl &photoUrl);
@@ -136,90 +121,6 @@ class KGAPICONTACTS_EXPORT Contact : public KGAPI2::Object,
      */
     QDateTime updated() const;
 
-    /**
-     * @brief Sets name of contact's spouse.
-     *
-     * @param name
-     */
-    void setSpousesName(const QString &name);
-
-    /**
-     * @brief Returns name of contacts' spouse
-     */
-    QString spousesName() const;
-
-    /**
-     * @brief Sets name of contact's manager.
-     *
-     * @param name
-     */
-    void setManagersName(const QString &name);
-
-    /**
-     * @brief Returns name of contact's manager.
-     */
-    QString managersName() const;
-
-    /**
-     * @brief Sets assistant's name.
-     *
-     * @param name
-     */
-    void setAssistantsName(const QString &name);
-
-    /**
-     * @brief Returns name of contact's assistant.
-     */
-    QString assistantsName() const;
-
-    /**
-     * @brief Sets contact's profession.
-     *
-     * @param profession
-     */
-    void setProfession(const QString &profession);
-
-    /**
-     * @brief Returns contact's profession.
-     */
-    QString profession() const;
-
-    /**
-     * @brief Sets address of contact's office.
-     *
-     * @param office
-     */
-    void setOffice(const QString &office);
-
-    /**
-     * @brief Returns address of contacts' office.
-     */
-    QString office() const;
-
-    /**
-     * @brief Sets date of contact's anniversary.
-     *
-     * @param anniversary
-     */
-    void setAnniversary(const QString &anniversary);
-
-    /**
-     * @brief Returns date of contact's anniversary
-     */
-    QString anniversary() const;
-
-    /**
-     * @brief Sets URL of contact's blog.
-     *
-     * @param url
-     */
-    void setBlogFeed(const QString &url);
-
-    /**
-     * @brief Returns URL of contact's blog.
-     */
-    QString blogFeed() const;
-
     /**
      * @brief Set list of groups the contact is member of.
      *
@@ -300,7 +201,7 @@ class KGAPICONTACTS_EXPORT Contact : public KGAPI2::Object,
     /**
      * @brief Converts Google Scheme URL to phone number type.
      *
-     * @parman scheme
+     * @param scheme
      */
     static KContacts::PhoneNumber::Type phoneSchemeToType(const QString &scheme);
 
@@ -324,6 +225,7 @@ class KGAPICONTACTS_EXPORT Contact : public KGAPI2::Object,
      * @brief Contacts Google scheme URL to email type.
      */
     static QString emailSchemeToProtocolName(const QString &scheme);
+    static KContacts::Email::Type emailSchemeToProtocolType(const QString &scheme);
 
   private:
     class Private;
@@ -333,4 +235,3 @@ class KGAPICONTACTS_EXPORT Contact : public KGAPI2::Object,
 
 } // namespace KGAPI2
 
-#endif /* LIBKGAPI2_CONTACT_H */
