@@ -8,7 +8,7 @@
 #include "tasklistfetchjob.h"
 #include "tasksservice.h"
 #include "account.h"
-#include "../debug.h"
+#include "debug.h"
 #include "tasklist.h"
 #include "utils.h"
 
